<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Дюйм</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Фут</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Миля</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Міліметр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Сантиметр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Метр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Кілометр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Мікродюйм</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Міл</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Ярд</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Ангстрем</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Нанометр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Мікрометр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Дециметр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Декаметр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Гектометр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Гігаметр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Астрономічна одиниця</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Світловий рік</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Парсек</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>За шаром</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>За блоком</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Червоний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Зелений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Синій</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Бірюзовий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Пурпурний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Жовтий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Помаранчевий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Темно-червоний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Темно-зелений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Темно-синій</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Темно-бірюзовий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Темно-пурпурний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Темно-жовтий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Чорний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Світло-сірий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Білий</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Інші...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>Поточний ідентифікатор шару</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Одиниці креслення</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Масштаб типу лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Шрифт розмірів</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+73"/>
        <location filename="../src/core/RLayer.cpp" line="+95"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="+81"/>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Приховано</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pixel Unit</source>
        <translation>Піксельна одиниця</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Початок координат</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+2"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Макет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Належить посиланню</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Зовнішнє посилання</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Виявлено циклічне (рекурсивне) блочне посилання:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Назва блоку:</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>Пов&apos;язаний бло</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Зовнішнє посилання</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Позиція</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+3"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Кут</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Стовпці</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Ряди</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Відстань між стовпчиками</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Відстань між рядами</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Атрибути</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overall scale</source>
        <translation>Загальний масштаб</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear measurement factor</source>
        <translation>Коефіцієнт лінійних вимірювань</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Висота тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Зазор розмірної лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Розмір стрілки</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Крок розмірної лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Виступ виносної лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Відступ виносної лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Вертикальне положення тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text horizontal</source>
        <translation>Горизонтальний текст</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Розмір засічки</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Лінійний формат</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Десяткові знаки</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Десятковий роздільник</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Пропуск нулів</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Кутовий формат</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Кутові десяткові знаки</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Пропуск кутових нулів</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Архітектурна засічка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Колір тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Блок стрілки</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Блок стрілки 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Блок стрілки 2</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+94"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block</source>
        <translation>Блок</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Шар</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+9"/>
        <source>Linetype</source>
        <translation>Тип лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Масштаб типу лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Товщина лінії</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Відображуваний колір</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Порядок відображення</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Ідентифікатор батьківського елемента</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Межа</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Знизу</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Зверху</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Висота</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="-7"/>
        <source>Off</source>
        <translation>Вимкнений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Заморожений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Заблокований</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Згорнутий</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Друкується</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Прив&apos;язуваний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Вимкнення = заморозити</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="-23"/>
        <source>Tab Order</source>
        <translation>Порядок вкладок</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Мінімальні межі</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Максимальні межі</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>База вставки</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Мінімальні габарити</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Максимальні габарити</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Довільний</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Ідентифікатор</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Захищений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Вибраний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Об&apos;єкт-невидимка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Робочий набір</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Простий</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Позиція тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Звичайний текст</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Назва шрифту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Висота тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Ширина тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Кут нахилу тексту</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Масштаб за X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Напівжирний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Міжрядковий інтервал</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Вирівнювання</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Горизонтальне</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Вертикальне</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Віддзеркалений</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Перевернутий</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Обертання</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Увімкнений</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Центр виду</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Ціль виду</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Загальний</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Заморожені шари</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>ID шару</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Потрібно виділити</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Метрична</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Шаблон</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>За шаром</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>За блоком</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Суцільна</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Межова</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Осьова</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Штрихпунктирна</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Штрихова</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Ділильна</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Пунктирна</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Невидима</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Фантомна</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO штрихова</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO штрихова розріджена</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO штрихпунктирна, довгий штрих</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO штрихпунктирна, довгий штрих, подвійна точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO штрихпунктирна, довгий штрих, потрійна точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO пунктирна</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO штрихова, довгий штрих, короткий штрих</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO штрихова, довгий штрих, подвійний короткий штрих</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO штрихпунктирна</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO штрихпунктирна, подвійний штрих, точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO штрихпунктирна, штрих, подвійна точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO штрихпунктирна, подвійний штрих, подвійна точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO штрихпунктирна, потрійна точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO штрихпунктирна, подвійний штрих, потрійна точка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Гаряче водопостачання</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Гаряча вода</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Газопровід</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Покриття</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Зигзаг</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Шляхи</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Лінія огорожі 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Лінія огорожі 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Точка 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Точка 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Виробництво</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Вода</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Дренаж</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Дренаж реверсивний</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Комунікація</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Електричний</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Низька напруга</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Висока напруга</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Повітряні лінії електропередач</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Каналізація</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Напірна каналізація</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>За шаром</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>За блоком</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>За замовчуванням</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58 мм</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00 мм (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11 мм</translation>
    </message>
</context>
</TS>
